==> primordial_harvest-fabric-1.21.1-21.1.2-sources.jar: net/darkhax/primordialharvest/common/impl/Helper.java <==
package net.darkhax.primordialharvest.common.impl;

import java.util.List;
import net.minecraft.class_1301;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_173;
import net.minecraft.class_1799;
import net.minecraft.class_181;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_3218;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_8567;

public class Helper {

    private static final class_238 INSIDE_CAULDRON = class_2248.method_9541(2, 4, 2, 14, 16, 14).method_1090().getFirst();

    public static void dropLoot(class_1937 level, class_2338 pos, class_5321<class_52> tableId, class_1657 player, class_1799 tool) {
        if (!level.field_9236 && level instanceof class_3218 serverLevel) {
            final class_8567 params = new class_8567.class_8568(serverLevel)
                    .method_51874(class_181.field_1224, level.method_8320(pos))
                    .method_51874(class_181.field_24424, pos.method_46558())
                    .method_51874(class_181.field_1229, tool)
                    .method_51874(class_181.field_1226, player)
                    .method_51871(player.method_7292())
                    .method_51875(class_173.field_1172);
            final class_52 table = level.method_8503().method_58576().method_58295(tableId);
            for (class_1799 stack : table.method_51878(params)) {
                class_2248.method_9577(level, pos, stack);
            }
        }
    }

    public static void shrink(class_1542 entity) {
        entity.method_6983().method_7934(1);
        if (entity.method_6983().method_7960()) {
            entity.method_31472();
        }
    }

    public static void checkReagents(class_1542 entity) {
        if (entity.method_6983().method_31573(Content.PHILOSOPHER_REAGENTS)) {
            final class_2338 position = entity.method_24515();
            final class_2680 container = entity.method_37908().method_8320(position);
            if (container.method_27852(class_2246.field_27097)) {
                final int level = container.method_11654(class_2741.field_12513);
                if (level > 0) {
                    final List<class_1542> items = entity.method_37908().method_8390(class_1542.class, new class_238(position), class_1301.field_6154);
                    if (items.size() >= 3) {
                        class_1542 sulfur = null;
                        class_1542 mercury = null;
                        class_1542 salt = null;
                        for (class_1542 item : items) {
                            if (sulfur != null && mercury != null && salt != null) {
                                break;
                            }
                            final class_1799 stack = item.method_6983();
                            if (sulfur == null && stack.method_31574(Content.RUMBLEPEA_FRUIT.get())) {
                                sulfur = item;
                            }
                            else if (mercury == null && stack.method_31574(Content.SPIRESHUCK_FRUIT.get())) {
                                mercury = item;
                            }
                            else if (salt == null && stack.method_31574(Content.PALEOGOURD_FRUIT.get())) {
                                salt = item;
                            }
                        }
                        if (sulfur != null && mercury != null && salt != null) {
                            shrink(sulfur);
                            shrink(mercury);
                            shrink(salt);
                            entity.method_37908().method_8652(position, Content.BLOOD_CAULDRON_BLOCK.get().method_9564().method_11657(class_2741.field_12513, level), 2);
                        }
                    }
                }
            }
        }
    }
}

==> primordial_harvest-fabric-1.21.1-21.1.9-sources.jar: net/darkhax/primordialharvest/common/impl/Helper.java <==
package net.darkhax.primordialharvest.common.impl;

import net.darkhax.bookshelf.common.api.function.TriFunction;
import net.minecraft.class_1301;
import net.minecraft.class_1542;
import net.minecraft.class_1657;
import net.minecraft.class_173;
import net.minecraft.class_1799;
import net.minecraft.class_181;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_238;
import net.minecraft.class_2680;
import net.minecraft.class_2741;
import net.minecraft.class_3218;
import net.minecraft.class_52;
import net.minecraft.class_5321;
import net.minecraft.class_8567;
import java.util.List;

public class Helper {

    public static TriFunction<class_2680, class_1922, class_2338, Float> GET_GROWTH_SPEED;

    public static void dropLoot(class_1937 level, class_2338 pos, class_5321<class_52> tableId, class_1657 player, class_1799 tool) {
        if (!level.field_9236 && level instanceof class_3218 serverLevel) {
            final class_8567 params = new class_8567.class_8568(serverLevel)
                    .method_51874(class_181.field_1224, level.method_8320(pos))
                    .method_51874(class_181.field_24424, pos.method_46558())
                    .method_51874(class_181.field_1229, tool)
                    .method_51874(class_181.field_1226, player)
                    .method_51871(player.method_7292())
                    .method_51875(class_173.field_1172);
            final class_52 table = level.method_8503().method_58576().method_58295(tableId);
            for (class_1799 stack : table.method_51878(params)) {
                class_2248.method_9577(level, pos, stack);
            }
        }
    }

    public static void shrink(class_1542 entity) {
        entity.method_6983().method_7934(1);
        if (entity.method_6983().method_7960()) {
            entity.method_31472();
        }
    }

    public static void checkReagents(class_1542 entity) {
        if (entity.method_6983().method_31573(Content.PHILOSOPHER_REAGENTS)) {
            final class_2338 position = entity.method_24515();
            final class_2680 container = entity.method_37908().method_8320(position);
            if (container.method_27852(class_2246.field_27097)) {
                final int level = container.method_11654(class_2741.field_12513);
                if (level > 0) {
                    final List<class_1542> items = entity.method_37908().method_8390(class_1542.class, new class_238(position), class_1301.field_6154);
                    if (items.size() >= 3) {
                        class_1542 sulfur = null;
                        class_1542 mercury = null;
                        class_1542 salt = null;
                        for (class_1542 item : items) {
                            if (sulfur != null && mercury != null && salt != null) {
                                break;
                            }
                            final class_1799 stack = item.method_6983();
                            if (sulfur == null && stack.method_31574(Content.RUMBLEPEA_FRUIT.get())) {
                                sulfur = item;
                            }
                            else if (mercury == null && stack.method_31574(Content.SPIRESHUCK_FRUIT.get())) {
                                mercury = item;
                            }
                            else if (salt == null && stack.method_31574(Content.PALEOGOURD_FRUIT.get())) {
                                salt = item;
                            }
                        }
                        if (sulfur != null && mercury != null && salt != null) {
                            shrink(sulfur);
                            shrink(mercury);
                            shrink(salt);
                            entity.method_37908().method_8652(position, Content.BLOOD_CAULDRON_BLOCK.get().method_9564().method_11657(class_2741.field_12513, level), 2);
                        }
                    }
                }
            }
        }
    }
}
